### Name: effx
### Title: Function to calculate effects
### Aliases: effx
### Keywords: models regression

### ** Examples

library(Epi)
data(births)
births$hyp <- factor(births$hyp,labels=c("normal","hyper"))
births$sex <- factor(births$sex,labels=c("M","F"))

# bweight is the birth weight of the baby in gms, and is a metric
# response (the default) 

# effect of hypertension on birth weight
effx(bweight,exposure=hyp,data=births) 
# effect of hypertension on birth weight stratified by sex
effx(bweight,exposure=hyp,strata=sex,data=births) 
# effect of hypertension on birth weight controlled for sex
effx(bweight,exposure=hyp,control=sex,data=births) 
# effect of gestation time on birth weight
effx(bweight,exposure=gestwks,data=births) 
# effect of gestation time on birth weight stratified by sex
effx(bweight,exposure=gestwks,strata=sex,data=births) 
# effect of gestation time on birth weight controlled for sex
effx(bweight,exposure=gestwks,control=sex,data=births) 

# lowbw is a binary response coded 1 for low birth weight and 0 otherwise
# effect of hypertension on low birth weight
effx(lowbw,type="binary",exposure=hyp,data=births)
# etc.



